@@ -1,7 +1,9 @@
 import requests
 import time
-import urlparse
-import urllib
+
+from django.utils.encoding import force_text
+from django.utils.http import urlencode
+from django.utils.six.moves.urllib.parse import parse_qs
 
 from paypal import exceptions
 
@@ -14,13 +16,7 @@ def post(url, params):
     :url: URL to post to
     :params: Dict of parameters to include in post payload
     """
-
-    # Ensure all values are bytestrings before passing to urllib
-    for k in params.keys():
-        if type(params[k]) == unicode:
-            params[k] = params[k].encode('utf-8')
-    payload = urllib.urlencode(params.items())
-
+    payload = urlencode(params)
     start_time = time.time()
     response = requests.post(
         url, payload,
@@ -30,8 +26,8 @@ def post(url, params):
 
     # Convert response into a simple key-value format
     pairs = {}
-    for key, values in urlparse.parse_qs(response.content).items():
-        pairs[key.decode('utf-8')] = values[0].decode('utf-8')
+    for key, values in parse_qs(response.content).items():
+        pairs[force_text(key)] = force_text(values[0])
 
     # Add audit information
     pairs['_raw_request'] = payload
